@@ -1,5 +1,7 @@
 #!/usr/bin/env python
-
+from __future__ import print_function
+import stretch_body.robot_params
+stretch_body.robot_params.RobotParams.set_logging_level("DEBUG")
 import stretch_body.head as head
 from stretch_body.hello_utils import *
 import sys
@@ -10,7 +12,8 @@ parser=argparse.ArgumentParser(description='Jog the head from the keyboard')
 args=parser.parse_args()
 
 h=head.Head()
-h.startup()
+if not h.startup():
+    exit()
 
 v_des=[h.motors['head_pan'].params['motion']['default']['vel'], h.motors['head_tilt'].params['motion']['default']['vel']]
 a_des=[h.motors['head_pan'].params['motion']['default']['accel'], h.motors['head_tilt'].params['motion']['default']['accel']]
@@ -25,17 +28,17 @@ def menu_top():
     print('e: ahead')
     print('f: back')
     print('g: tool')
-    print 'h: wheels'
-    print 'i: left'
-    print 'j: up'
-    print 'p: pan go to pos ticks'
-    print 't: tilt go to pos ticks'
-    print 'x: home'
-    print '1: speed slow'
-    print '2: speed default'
-    print '3: speed fast'
-    print '4: speed max'
-    print '-------------------'
+    print('h: wheels')
+    print('i: left')
+    print('j: up')
+    print('p: pan go to pos ticks')
+    print('t: tilt go to pos ticks')
+    print('x: home')
+    print('1: speed slow')
+    print('2: speed default')
+    print('3: speed fast')
+    print('4: speed max')
+    print('-------------------')
 
 def step_interaction():
     global v_des, a_des
